/*

   hook.io hook that outputs to notify-send!

*/


var Hook = require('hook.io').Hook,
    util = require('util'),
    growl = require('notify-send');

var NotifySend = exports.NotifySend = function(options){
  Hook.call(this, options);
  var self = this;

  self.on('**::growl', function (msg) {
    var output = {};

    // simple string notifications
    if (typeof msg === "string") {
      return growl.notify(msg);
    }

    // body (defaults to stringified arguments)
    if (msg.body) {
      output.body = msg.body;
    }
    else {
      try {
        // util.inspect was being 'weird'. :(
        output.body = JSON.stringify(Array.prototype.slice.call(arguments), null, 2);
      }
      catch (e) {
        output.body = String(arguments);
      }
    }

    // summary (defaults to this.event)
    if (msg.summary) {
      output.summary = msg.summary;
    }
    else {
      output.summary = this.event;
    }


    // logging levels
    switch (msg.level) {
      case "low":
        growl.low.notify(output.summary, output.body);
        break;
      case "normal":
        growl.normal.notify(output.summary, output.body);
        break;
      case "critical":
        growl.critical.notify(output.summary, output.body);
        break;
      default:
        growl.notify(output.summary, output.body);
    }

  });

};

// NotifySend inherits from Hook
util.inherits(NotifySend, Hook);
